@@ -1,7 +1,7 @@
 ## Domain Registry Interface, NIC.AT EPP extensions
 ## Contributed by Michael Braunoeder from NIC.AT <mib@nic.at>
 ##
-## Copyright (c) 2006,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006-2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006-2009,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -70,7 +70,7 @@ sub setup
  return;
 }
 
-sub default_extensions { return qw/AT::Domain AT::Contact AT::ATResult AT::Message/; }
+sub default_extensions { return qw/AT::Domain AT::Contact AT::ATResult AT::Message SecDNS/; }
 
 ####################################################################################################
 1;
