@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CentralNic Web Forwarding EPP extension
 ## (http://labs.centralnic.com/epp/ext/wf.php)
 ##
-## Copyright (c) 2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -16,6 +16,7 @@
 package Net::DRI::Protocol::EPP::Extensions::CentralNic::WebForwarding;
 
 use strict;
+use warnings;
 
 =pod
 
@@ -45,7 +46,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -85,6 +86,7 @@ sub info_parse
  return unless @c;
 
  $rinfo->{domain}->{$oname}->{web_forwarding}=$c[0]->getFirstChild()->getData();
+ return;
 }
 
 ############ Transform commands
@@ -99,6 +101,7 @@ sub create
  my $eid=$mes->command_extension_register('wf:create',sprintf('xmlns:wf="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('wf')));
  my @n=(['wf:url',$rd->{web_forwarding}]);
  $mes->command_extension($eid,\@n);
+ return;
 }
 
 sub update
@@ -112,6 +115,7 @@ sub update
  my $eid=$mes->command_extension_register('wf:update',sprintf('xmlns:wf="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('wf')));
  my @n=(['wf:url',$toset]);
  $mes->command_extension($eid,\@n);
+ return;
 }
 
 ####################################################################################################
