@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EURid Domain EPP extension commands
 ## (based on EURid registration_guidelines_v1_0E-epp.pdf)
 ##
-## Copyright (c) 2005-2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2013,2015 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##               2014 Michael Kefeder <michael.kefeder@world4you.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -51,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2013,2015 Patrick Mevzek <netdri@dotandco.com>.
               2014 Michael Kefeder <michael.kefeder@world4you.com>.
 All rights reserved.
 
@@ -210,15 +210,20 @@ sub info_parse
    $status->add('pendingTransfer');
    my %p;
    my $cs=$po->create_local_object('contactset');
+   my %ccache;
    foreach my $subel (Net::DRI::Util::xml_list_children($c))
    {
     my ($subname,$subc)=@$subel;
     if ($subname eq 'registrant')
     {
-     $cs->set($po->create_local_object('contact')->srid($subc->textContent()),'registrant');
+     my $id=$subc->textContent();
+     $ccache{$id}=$po->create_local_object('contact')->srid($id) unless exists $ccache{$id};
+     $cs->set($ccache{$id},'registrant');
     } elsif ($subname eq 'contact')
     {
-     $cs->add($po->create_local_object('contact')->srid($subc->textContent()),$subc->getAttribute('type'));
+     my $id=$subc->textContent();
+     $ccache{$id}=$po->create_local_object('contact')->srid($id) unless exists $ccache{$id};
+     $cs->add($ccache{$id},$subc->getAttribute('type'));
     } elsif ($subname eq 'initiationDate')
     {
      $p{initiationDate}=$po->parse_iso8601($subc->textContent());
