@@ -1,6 +1,6 @@
 ## Domain Registry Interface, FCCN (.PT) EPP extensions
 ##
-## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -47,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,9 +63,11 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub setup
 {
- my ($self,$rp)=@_;
- $self->ns({ ptdomain  => ['http://www.dns.pt/xml/epp/ptdomain-1.0','ptdomain-1.0.xsd'],
-             ptcontact => ['http://www.dns.pt/xml/epp/ptcontact-1.0','ptcontact-1.0.xsd'],
+ my ($self,$rp,$params)=@_;
+ my $namespace_base = (defined($params) && ref($params) eq "HASH" && defined($params->{"namespace_base"})) ? $params->{"namespace_base"} : "http://www.dns.pt/xml/epp";
+
+ $self->ns({ ptdomain  => ["$namespace_base/ptdomain-1.0",'ptdomain-1.0.xsd'],
+             ptcontact => ["$namespace_base/ptcontact-1.0",'ptcontact-1.0.xsd'],
            });
  $self->capabilities('contact_update','status',undef);
  $self->default_parameters({domain_create => { auth => { pw => '' } } }); ## domain:authInfo is not used by FCCN
