@@ -1,7 +1,7 @@
 ## Domain Registry Interface, Net::DRI::Protocol::EPP class for .SE
 ## Contributed by Elias Sidenbladh and Ulrich Wisser from NIC SE
 ##
-## Copyright (c) 2006,2008-2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008-2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,9 +11,6 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::SE;
@@ -23,8 +20,6 @@ use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
-our $VERSION=do { my @r=(q$Revision: 1.7 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -53,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008-2010 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008-2011 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -71,7 +66,7 @@ sub setup
 {
     my ($self,$rp)=@_;
     my $version=$self->version();
-    $self->ns({iis=>['urn:se:iis:xml:epp:iis-1.1','iis-1.1.xsd']});
+    $self->ns({iis=>['urn:se:iis:xml:epp:iis-1.2','iis-1.2.xsd']}); ## this will be updated if needed after server greeting
     return;
 }
 
